ImageHrefResolver

Struct ImageHrefResolver 

pub struct ImageHrefResolver<'a> {
    pub resolve_data: ImageHrefDataResolverFn<'a>,
    pub resolve_string: ImageHrefStringResolverFn<'a>,
}
An xlink:href resolver for <image> elements.

This type can be useful if you want to have an alternative xlink:href handling to the default one. For example, you can forbid access to local files (which is allowed by default) or add support for resolving actual URLs (usvg doesn’t do any network requests).

Fields

resolve_data: ImageHrefDataResolverFn<'a>

Resolver function that will be used when xlink:href contains a Data URL.

A function would be called with mime, decoded base64 data and parsing options.

resolve_string: ImageHrefStringResolverFn<'a>

Resolver function that will be used to handle an arbitrary string in xlink:href.

Implementations

Source

impl ImageHrefResolver<'_>

pub fn default_data_resolver() -> ImageHrefDataResolverFn<'static>

Creates a default Data URL resolver closure.

base64 encoded data is already decoded.

The default implementation would try to load JPEG, PNG, GIF, WebP, SVG and SVGZ types. Note that it will simply match the mime or data’s magic. The actual images would not be decoded. It’s up to the renderer.

pub fn default_string_resolver() -> ImageHrefStringResolverFn<'static>

Creates a default string resolver (no_std fallback).

Without filesystem access, this resolver always returns None.